# Log

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**log** | **str** | log | [optional] [readonly] 
**stream** | **str** | log stream | [optional] [readonly] 
**timestamp** | **str** | timestamp of log | [optional] [readonly] 
**app** | **str** | name of application associated with log | [optional] [readonly] 
**org_id** | **str** | unique shortuuid for the  organisation | [optional] [readonly] 
**sub_org_id** | **str** | unique shortuuid for the sub-organisation | [optional] [readonly] 
**env** | **str** | environment that app is running in | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


